@@ -4,7 +4,7 @@ from autocorrect import Speller
 import re
 import os
 import traceback
-from utils import *
+from .utils import *
 from functools import partial
 
 class pdfextracter:
